@@ -7,16 +7,6 @@ from doit.control import TaskControl, TaskDispatcher, ExecNode, no_none
 
 
 
-# generator compatibility for 2.5
-# http://www.voidspace.org.uk/python/articles/porting-mock-to-python-3.shtml
-try:
-    next
-except NameError: # pragma: nocover
-    def next(gen):
-        return gen.next()
-
-
-
 class TestTaskControlInit(object):
 
     def test_addTask(self):
